@@ -5,6 +5,7 @@ Current available mobility metrics include:
     - Planform overlap from Wickert et al 2013
     - Reworking index from Wickert et al 2013
     - Channel abandonment from Liang et al 2016
+    - Channelized response variance from Jarriel et al 2019
 
 Also included are functions to fit curves to the output from the mobility
 functions, allowing for decay constants and timescales to be quantified.
@@ -615,3 +616,140 @@ def channel_presence(chmap):
     # calculation of channel presence is actually very simple
     channel_presence = np.sum(chans, axis=0) / chans.shape[0]
     return channel_presence
+
+
+def calculate_channelized_response_variance(
+                  arr, threshold=0.2, normalize_input=False,
+                  normalize_output=False):
+    """
+    Calculate the Channelized Response Variance (CRV).
+
+    This function takes a t-x-y array and calculates its directional CRV.
+    In short, the function does the following:
+        1. Normalizes the array at each time slice if desired.
+        2. Calculates the CRV magnitude (aka variance along time-axis) and
+           normalizes this array if desired.
+        3. Does linear regressions through time for each pixel and returns
+           the slopes.
+        4. Calculates the directional CRV using a slope threshold value.
+        5. Returns the CRV magnitude, slopes, and directional CRV
+           values
+
+    Parameters
+    ----------
+    arr : numpy.ndarray
+        A t-x-y 3-D array to calculate the CRV on.
+
+    threshold : float, optional
+        Threshold for CRV calculation. The default is 0.2.
+
+    normalize_input : bool, optional
+        Whether to normalize the input images pixel values to 0-1.
+        The default is False.
+
+    normalize_output : bool, optional
+        Whether to normalize the output image pixel values to 0-1.
+        The default is False.
+
+    Returns
+    -------
+    crv_magnitude : numpy.ndarray
+        A t-x-y 3-D array with the CRV magnitude.
+
+    slopes : numpy.ndarray
+        A t-x-y 3-D array with the slopes of the linear regressions.
+
+    directional_crv : numpy.ndarray
+        A t-x-y 3-D array with the directional CRV.
+
+    Examples
+    --------
+
+    .. plot::
+        :include-source:
+
+        >>> # Load overhead imagery sample data from Savi et al 2020
+        >>> img, _ = dm.sample_data.savi2020()
+        >>> # Calculate the CRV on the "Red" band
+        >>> crv_mag, slopes, crv = dm.mobility.calculate_channelized_response_variance(
+        ...    img['red'].data, threshold=0.0,
+        ...    normalize_input=True, normalize_output=True)
+        >>> # plot the results
+        >>> fig, ax = plt.subplots(1, 3, figsize=(13, 5))
+        >>> i0 = ax[0].imshow(crv_mag, vmin=0, vmax=1)
+        >>> ax[0].set_title('CRV Magnitude')
+        >>> dm.plot.append_colorbar(i0, ax=ax[0], size=10)
+        >>> s_ex = np.max([np.abs(slopes.min()), slopes.max()])
+        >>> i1 = ax[1].imshow(slopes, vmin=-1*s_ex, vmax=s_ex, cmap='PuOr')
+        >>> ax[1].set_title('CRV Slopes')
+        >>> dm.plot.append_colorbar(i1, ax=ax[1], size=10)
+        >>> i2 = ax[2].imshow(crv, vmin=-1, vmax=1, cmap='seismic')
+        >>> ax[2].set_title('Directional CRV')
+        >>> dm.plot.append_colorbar(i2, ax=ax[2], size=10)
+        >>> fig.suptitle('CRV of Red band from imagery from Savi et al 2020')
+        >>> plt.show()
+    """
+    # normalize the input array if desired
+    if normalize_input is True:
+        for t in range(arr.shape[0]):
+            arr[t, ...] = arr[t, ...] / np.max(arr[t, ...])
+
+    # calculate the CRV magnitude
+    crv_magnitude = np.var(arr, axis=0)  # calculate variance
+    # normalize if desired
+    if normalize_output is True:
+        crv_magnitude = crv_magnitude / crv_magnitude.max()
+
+    # calculate the slopes of the linear regressions
+    slopes = _calculate_temporal_linear_slope(arr)
+
+    # calculate the directional CRV
+    # threshold the slopes array
+    # first determine which slopes are below the threshold
+    slopes_abs = np.abs(slopes)
+    slopes_abs[slopes_abs < threshold] = 0
+    slopes_abs[slopes_abs >= threshold] = 1
+    # zero out the CRV values where the slope is below the threshold
+    slopes_thresholded = slopes * slopes_abs
+    # then assign -1 and 1 values where they belong
+    slopes_thresholded[slopes_thresholded <= -1*threshold] = -1
+    slopes_thresholded[slopes_thresholded >= threshold] = 1
+    # final calculation of directional CRV
+    directional_crv = slopes_thresholded * crv_magnitude
+
+    # return the CRV magnitude, slopes, and directional CRV
+    return crv_magnitude, slopes, directional_crv
+
+
+def _calculate_temporal_linear_slope(stack):
+    """
+    Fits linear regressions and calculates slopes.
+
+    This function calculates the slopes of the linear regressions for each
+    pixel through time (axis 0). The slopes are the slope of the
+    linear regression through time for each pixel.
+
+    Parameters
+    ----------
+    stack : numpy array
+        Stack of images as a t-x-y numpy array.
+
+    Returns
+    -------
+    slopes : numpy array
+        Slopes as a t-x-y numpy array.
+
+    """
+    # define x and y for linear regression
+    x = np.arange(0, stack.shape[0])  # simple 0-n vector
+    # convert stack from size [t,x,y] to [t, x*y]
+    y = np.reshape(stack, [stack.shape[0], stack.shape[1] * stack.shape[2]])
+
+    # do least squares regression
+    # based on stackoverflow: https://stackoverflow.com/a/20344897
+    slopes, _ = np.linalg.lstsq(np.c_[x, np.ones_like(x)], y, rcond=None)[0]
+
+    # reshape
+    slopes = np.reshape(slopes, [stack.shape[1], stack.shape[2]])
+
+    return slopes
